@@ -705,53 +705,6 @@ uint8_t *mlt_frame_get_alpha( mlt_frame self )
 	return alpha;
 }
 
-/** Get the short name for an audio format.
- *
- * You do not need to deallocate the returned string.
- * \public \memberof mlt_frame_s
- * \param format an audio format enum
- * \return a string for the name of the image format
- */
-
-const char * mlt_audio_format_name( mlt_audio_format format )
-{
-	switch ( format )
-	{
-		case mlt_audio_none:   return "none";
-		case mlt_audio_s16:    return "s16";
-		case mlt_audio_s32:    return "s32";
-		case mlt_audio_s32le:  return "s32le";
-		case mlt_audio_float:  return "float";
-		case mlt_audio_f32le:  return "f32le";
-		case mlt_audio_u8:     return "u8";
-	}
-	return "invalid";
-}
-
-/** Get the amount of bytes needed for a block of audio.
-  *
-  * \public \memberof mlt_frame_s
-  * \param format an audio format enum
-  * \param samples the number of samples per channel
-  * \param channels the number of channels
-  * \return the number of bytes
-  */
-
-int mlt_audio_format_size( mlt_audio_format format, int samples, int channels )
-{
-	switch ( format )
-	{
-		case mlt_audio_none:   return 0;
-		case mlt_audio_s16:    return samples * channels * sizeof( int16_t );
-		case mlt_audio_s32le:
-		case mlt_audio_s32:    return samples * channels * sizeof( int32_t );
-		case mlt_audio_f32le:
-		case mlt_audio_float:  return samples * channels * sizeof( float );
-		case mlt_audio_u8:     return samples * channels;
-	}
-	return 0;
-}
-
 /** Get the audio associated to the frame.
  *
  * You should express the desired format, frequency, channels, and samples as inputs. As long
@@ -761,7 +714,7 @@ int mlt_audio_format_size( mlt_audio_format format, int samples, int channels )
  * on properties and filters. You do not need to supply a pre-allocated
  * buffer, but you should always supply the desired audio format.
  * The audio is always in interleaved format.
- * You should use the \p mlt_sample_calculator to determine the number of samples you want.
+ * You should use the \p mlt_audio_sample_calculator to determine the number of samples you want.
  *
  * \public \memberof mlt_frame_s
  * \param self a frame
@@ -888,13 +841,13 @@ unsigned char *mlt_frame_get_waveform( mlt_frame self, int w, int h )
 	int channels = 2;
 	mlt_producer producer = mlt_frame_get_original_producer( self );
 	double fps = mlt_producer_get_fps( mlt_producer_cut_parent( producer ) );
-	int samples = mlt_sample_calculator( fps, frequency, mlt_frame_get_position( self ) );
+	int samples = mlt_audio_calculate_frame_samples( fps, frequency, mlt_frame_get_position( self ) );
 
 	// Increase audio resolution proportional to requested image size
 	while ( samples < w )
 	{
 		frequency += 16000;
-		samples = mlt_sample_calculator( fps, frequency, mlt_frame_get_position( self ) );
+		samples = mlt_audio_calculate_frame_samples( fps, frequency, mlt_frame_get_position( self ) );
 	}
 
 	// Get the pcm data
@@ -985,51 +938,6 @@ void mlt_frame_close( mlt_frame self )
 
 /***** convenience functions *****/
 
-/** Determine the number of samples that belong in a frame at a time position.
- *
- * \public \memberof mlt_frame_s
- * \param fps the frame rate
- * \param frequency the sample rate
- * \param position the time position
- * \return the number of samples per channel
- */
-
-int mlt_sample_calculator( float fps, int frequency, int64_t position )
-{
-	/* Compute the cumulative number of samples until the start of this frame and the
-	cumulative number of samples until the start of the next frame. Round each to the
-	nearest integer and take the difference to determine the number of samples in
-	this frame.
-
-	This approach should prevent rounding errors that can accumulate over a large number
-	of frames causing A/V sync problems. */
-	return mlt_sample_calculator_to_now( fps, frequency, position + 1 )
-		 - mlt_sample_calculator_to_now( fps, frequency, position );
-}
-
-/** Determine the number of samples that belong before a time position.
- *
- * \public \memberof mlt_frame_s
- * \param fps the frame rate
- * \param frequency the sample rate
- * \param position the time position
- * \return the number of samples per channel
- * \bug Will this break when mlt_position is converted to double?
- */
-
-int64_t mlt_sample_calculator_to_now( float fps, int frequency, int64_t position )
-{
-	int64_t samples = 0;
-
-	if ( fps )
-	{
-		samples = (int64_t)( (double) position * (double) frequency / (double) fps +
-			( position < 0 ? -0.5 : 0.5 ) );
-	}
-
-	return samples;
-}
-
 void mlt_frame_write_ppm( mlt_frame frame )
 {
 	int width = 0;
@@ -1247,128 +1155,3 @@ int mlt_image_format_planes( mlt_image_format format, int width, int height, voi
 
 	return 0;
 }
-
-/** Get the short name for a channel configuration.
- *
- * You do not need to deallocate the returned string.
- * \public \member of mlt_frame_s
- * \param cfg a channel configuration enum
- * \return a string for the name of the channel configuration
- */
-
-const char * mlt_channel_layout_name( mlt_channel_layout layout )
-{
-	switch ( layout )
-	{
-		case mlt_channel_auto:           return "auto";
-		case mlt_channel_independent:    return "independent";
-		case mlt_channel_mono:           return "mono";
-		case mlt_channel_stereo:         return "stereo";
-		case mlt_channel_2p1:            return "2.1";
-		case mlt_channel_3p0:            return "3.0";
-		case mlt_channel_3p0_back:       return "3.0(back)";
-		case mlt_channel_4p0:            return "4.0";
-		case mlt_channel_quad_back:      return "quad";
-		case mlt_channel_quad_side:      return "quad(side)";
-		case mlt_channel_3p1:            return "3.1";
-		case mlt_channel_5p0_back:       return "5.0";
-		case mlt_channel_5p0:            return "5.0(side)";
-		case mlt_channel_4p1:            return "4.1";
-		case mlt_channel_5p1_back:       return "5.1";
-		case mlt_channel_5p1:            return "5.1(side)";
-		case mlt_channel_6p0:            return "6.0";
-		case mlt_channel_6p0_front:      return "6.0(front)";
-		case mlt_channel_hexagonal:      return "hexagonal";
-		case mlt_channel_6p1:            return "6.1";
-		case mlt_channel_6p1_back:       return "6.1(back)";
-		case mlt_channel_6p1_front:      return "6.1(front)";
-		case mlt_channel_7p0:            return "7.0";
-		case mlt_channel_7p0_front:      return "7.0(front)";
-		case mlt_channel_7p1:            return "7.1";
-		case mlt_channel_7p1_wide_side:  return "7.1(wide-side)";
-		case mlt_channel_7p1_wide_back:  return "7.1(wide)";
-	}
-	return "invalid";
-}
-
-/** Get the id of channel configuration from short name.
- *
- * \public \memberof mlt_frame_s
- * \param name the channel configuration short name
- * \return a channel configuration
- */
-
-mlt_channel_layout mlt_channel_layout_id( const char * name )
-{
-	if( name )
-	{
-		mlt_channel_layout c;
-		for( c = mlt_channel_auto; c <= mlt_channel_7p1_wide_back; c++ )
-		{
-			const char * v = mlt_channel_layout_name( c );
-			if( !strcmp( v, name ) )
-				return c;
-		}
-	}
-	return mlt_channel_auto;
-}
-
-/** Get the number of channels for a channel configuration.
- *
- * \public \memberof mlt_frame_s
- * \param cfg a channel configuration enum
- * \return the number of channels for the channel configuration
- */
-
-int mlt_channel_layout_channels( mlt_channel_layout layout )
-{
-	switch ( layout )
-	{
-		case mlt_channel_auto:           return 0;
-		case mlt_channel_independent:    return 0;
-		case mlt_channel_mono:           return 1;
-		case mlt_channel_stereo:         return 2;
-		case mlt_channel_2p1:            return 3;
-		case mlt_channel_3p0:            return 3;
-		case mlt_channel_3p0_back:       return 3;
-		case mlt_channel_4p0:            return 4;
-		case mlt_channel_quad_back:      return 4;
-		case mlt_channel_quad_side:      return 4;
-		case mlt_channel_3p1:            return 4;
-		case mlt_channel_5p0_back:       return 5;
-		case mlt_channel_5p0:            return 5;
-		case mlt_channel_4p1:            return 5;
-		case mlt_channel_5p1_back:       return 6;
-		case mlt_channel_5p1:            return 6;
-		case mlt_channel_6p0:            return 6;
-		case mlt_channel_6p0_front:      return 6;
-		case mlt_channel_hexagonal:      return 6;
-		case mlt_channel_6p1:            return 7;
-		case mlt_channel_6p1_back:       return 7;
-		case mlt_channel_6p1_front:      return 7;
-		case mlt_channel_7p0:            return 7;
-		case mlt_channel_7p0_front:      return 7;
-		case mlt_channel_7p1:            return 8;
-		case mlt_channel_7p1_wide_back:  return 8;
-		case mlt_channel_7p1_wide_side:  return 8;
-	}
-	return 0;
-}
-
-/** Get a default channel configuration for a given number of channels.
- *
- * \public \memberof mlt_frame_s
- * \param channels the number of channels
- * \return the default channel configuration
- */
-
-mlt_channel_layout mlt_channel_layout_default( int channels )
-{
-	mlt_channel_layout c;
-	for( c = mlt_channel_mono; c <= mlt_channel_7p1_wide_back; c++ )
-	{
-		if( mlt_channel_layout_channels( c ) == channels )
-			return c;
-	}
-	return mlt_channel_independent;
-}
