@@ -30,10 +30,6 @@
 #include <pthread.h>
 #include <sched.h>
 #ifdef _WIN32
-#ifdef _WIN32_WINNT
-#undef _WIN32_WINNT
-#endif
-#define _WIN32_WINNT 0x0601
 #include <windows.h>
 #endif
 #define MAX_SLICES 32
@@ -154,7 +150,13 @@ mlt_slices mlt_slices_init( int threads, int policy, int priority )
 	mlt_slices ctx = (mlt_slices)calloc( 1, sizeof( struct mlt_slices_s ) );
 	char *env = getenv( ENV_SLICES );
 #ifdef _WIN32
-	int cpus = GetActiveProcessorCount( ALL_PROCESSOR_GROUPS );
+	#if _WIN32_WINNT >= 0x0601
+		int cpus = GetActiveProcessorCount( ALL_PROCESSOR_GROUPS );
+	#else
+		SYSTEM_INFO info;
+		GetSystemInfo(&info);
+		int cpus = info.dwNumberOfProcessors;
+	#endif
 #else
 	int cpus = sysconf( _SC_NPROCESSORS_ONLN );
 #endif
