@@ -1,7 +1,6 @@
 /**
  * MltProperties.h - MLT Wrapper
- * Copyright (C) 2004-2015 Meltytech, LLC
- * Author: Charles Yates <charles.yates@gmail.com>
+ * Copyright (C) 2004-2020 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -42,10 +41,12 @@ namespace Mlt
 			Properties( );
 			Properties( bool dummy );
 			Properties( Properties &properties );
+			Properties( const Properties &properties );
 			Properties( mlt_properties properties );
 			Properties( void *properties );
 			Properties( const char *file );
 			virtual ~Properties( );
+			Properties& operator=( const Properties &properties );
 			virtual mlt_properties get_properties( );
 			int inc_ref( );
 			int dec_ref( );
@@ -64,6 +65,7 @@ namespace Mlt
 			void *get_data( const char *name, int &size );
 			void *get_data( const char *name );
 			int set( const char *name, const char *value );
+			int set_string( const char *name, const char *value );
 			int set( const char *name, int value );
 			int set( const char *name, int64_t value );
 			int set( const char *name, double value );
@@ -74,6 +76,7 @@ namespace Mlt
 			int parse( const char *namevalue );
 			char *get_name( int index );
 			char *get( int index );
+			char *get( int index, mlt_time_format );
 			void *get_data( int index, int &size );
 			void mirror( Properties &that );
 			int inherit( Properties &that );
@@ -97,6 +100,9 @@ namespace Mlt
 			int preset( const char *name );
 			int set_lcnumeric( const char *locale );
 			const char *get_lcnumeric( );
+			void clear( const char *name );
+			bool property_exists( const char *name );
+
 			char *get_time( const char *name, mlt_time_format = mlt_time_smpte_df );
 			char *frames_to_time( int, mlt_time_format = mlt_time_smpte_df );
 			int time_to_frames( const char* time );
