@@ -1,6 +1,6 @@
 /**
  * MltRepository.cpp - MLT Wrapper
- * Copyright (C) 2008 Dan Dennedy <dan@dennedy.org>
+ * Copyright (C) 2008-2017 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -35,8 +35,6 @@ Repository::Repository( mlt_repository repository ) :
 
 Repository::~Repository( )
 {
-	if ( instance )
-		mlt_repository_close( instance );
 	instance = NULL;
 }
 
