@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <framework/mlt.h>
@@ -22,13 +22,14 @@
 #include <assert.h>
 
 #include "filter_glsl_manager.h"
-#include <movit/diffusion_effect.h>
+#include <diffusion_effect.h>
 
 using namespace movit;
 
 static int get_image( mlt_frame frame, uint8_t **image, mlt_image_format *format, int *width, int *height, int writable )
 {
 	mlt_filter filter = (mlt_filter) mlt_frame_pop_service( frame );
+
 	mlt_properties properties = MLT_FILTER_PROPERTIES( filter );
 	GlslManager::get_instance()->lock_service( frame );
 	mlt_position position = mlt_filter_get_position( filter, frame );
@@ -40,6 +41,12 @@ static int get_image( mlt_frame frame, uint8_t **image, mlt_image_format *format
 	GlslManager::get_instance()->unlock_service( frame );
 	*format = mlt_image_glsl;
 	int error = mlt_frame_get_image( frame, image, format, width, height, writable );
+
+	if (*width < 1 || *height < 1) {
+		mlt_log_error( MLT_FILTER_SERVICE(filter), "Invalid size for get_image: %dx%d", *width, *height);
+		return error;
+	}
+
 	GlslManager::set_effect_input( MLT_FILTER_SERVICE( filter ), frame, (mlt_service) *image );
 	GlslManager::set_effect( MLT_FILTER_SERVICE( filter ), frame, new DiffusionEffect );
 	*image = (uint8_t *) MLT_FILTER_SERVICE( filter );
