@@ -30,6 +30,7 @@ extern mlt_filter filter_lift_gamma_gain_init( mlt_profile profile, mlt_service_
 extern mlt_filter filter_loudness_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
 extern mlt_filter filter_loudness_meter_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
 extern mlt_filter filter_lumakey_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
+extern mlt_filter filter_pillar_echo_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
 extern mlt_filter filter_invert_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
 extern mlt_filter filter_rgblut_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
 extern mlt_filter filter_sepia_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
@@ -64,6 +65,7 @@ MLT_REPOSITORY
 	MLT_REGISTER( filter_type, "loudness", filter_loudness_init );
 	MLT_REGISTER( filter_type, "loudness_meter", filter_loudness_meter_init );
 	MLT_REGISTER( filter_type, "lumakey", filter_lumakey_init );
+	MLT_REGISTER( filter_type, "pillar_echo", filter_pillar_echo_init );
 	MLT_REGISTER( filter_type, "rgblut", filter_rgblut_init );
 	MLT_REGISTER( filter_type, "sepia", filter_sepia_init );
 	MLT_REGISTER( filter_type, "spot_remover", filter_spot_remover_init );
@@ -87,6 +89,7 @@ MLT_REPOSITORY
 	MLT_REGISTER_METADATA( filter_type, "loudness", metadata, "filter_loudness.yml" );
 	MLT_REGISTER_METADATA( filter_type, "loudness_meter", metadata, "filter_loudness_meter.yml" );
 	MLT_REGISTER_METADATA( filter_type, "lumakey", metadata, "filter_lumakey.yml" );
+	MLT_REGISTER_METADATA( filter_type, "pillar_echo", metadata, "filter_pillar_echo.yml" );
 	MLT_REGISTER_METADATA( filter_type, "rgblut", metadata, "filter_rgblut.yml" );
 	MLT_REGISTER_METADATA( filter_type, "sepia", metadata, "filter_sepia.yml" );
 	MLT_REGISTER_METADATA( filter_type, "spot_remover", metadata, "filter_spot_remover.yml" );
