@@ -29,6 +29,8 @@
 
 #include "interp.h"
 
+#define MLT_AFFINE_MAX_DIMENSION (16000)
+
 static double alignment_parse( char* align )
 {
 	int ret = 0.0;
@@ -540,8 +542,10 @@ static int transition_get_image( mlt_frame a_frame, uint8_t **image, mlt_image_f
 
 	double geometry_w = result.w;
 	double geometry_h = result.h;
+	int fill = mlt_properties_get_int( properties, "fill" );
+	int distort = mlt_properties_get_int( properties, "distort" );
 
-	if ( !mlt_properties_get_int( properties, "fill" ) )
+	if ( !fill )
 	{
 		double geometry_dar = result.w * consumer_ar / result.h;
 
@@ -558,21 +562,32 @@ static int transition_get_image( mlt_frame a_frame, uint8_t **image, mlt_image_f
 	}
 
 	// Fetch the b frame image
-	if (mlt_properties_get_int(properties, "b_scaled") || mlt_properties_get_int(b_props, "always_scale")) {
-		// Request b frame image size just what is needed.
-		b_width = result.w;
-		b_height = result.h;
-		// Set the rescale interpolation to match the frame
-		mlt_properties_set( b_props, "rescale.interp", mlt_properties_get( a_props, "rescale.interp" ) );
-	} else if (scale_width != 1.0 || scale_height != 1.0) {
-		// Scale request of b frame image to consumer scale maintaining its aspect ratio.
-		b_height = *height;
-		b_width = b_height * b_dar / b_ar;
+	if (scale_width != 1.0 || scale_height != 1.0) {
+			// Scale request of b frame image to consumer scale maintaining its aspect ratio.
+			b_height = CLAMP(*height, 1, MLT_AFFINE_MAX_DIMENSION);
+			b_width  = CLAMP(b_height * b_dar / b_ar, 1, MLT_AFFINE_MAX_DIMENSION);
+			// Set the rescale interpolation to match the frame
+			mlt_properties_set( b_props, "rescale.interp", mlt_properties_get( a_props, "rescale.interp" ) );
+			// Disable padding (resize filter)
+			mlt_properties_set_int( b_props, "distort", 1 );
+	} else if (!mlt_properties_get_int(b_props, "interpolation_not_required")
+			   && (fill || distort || b_width > result.w || b_height > result.h
+				   || mlt_properties_get_int(properties, "b_scaled") || mlt_properties_get_int(b_props, "always_scale"))) {
+		// Request b frame image scaled to what is needed.
+		b_width  = CLAMP(result.w, 1, MLT_AFFINE_MAX_DIMENSION);
+		b_height = b_width * b_ar / b_dar;
+		if (b_height > MLT_AFFINE_MAX_DIMENSION) {
+			b_height = CLAMP(result.h, 1, MLT_AFFINE_MAX_DIMENSION);
+			b_width  = b_height * b_dar / b_ar;
+		}
 		// Set the rescale interpolation to match the frame
 		mlt_properties_set( b_props, "rescale.interp", mlt_properties_get( a_props, "rescale.interp" ) );
+		// Disable padding (resize filter)
 		mlt_properties_set_int( b_props, "distort", 1 );
 	} else {
-		// Request full resolution of b frame image.
+		// Request at resolution of b frame image. This only happens when not using fill or distort mode
+		// and the image is smaller than the rect with the intention to prevent scaling of the
+		// image and merely position and possibly transform.
 		mlt_properties_set_int( b_props, "rescale_width", b_width );
 		mlt_properties_set_int( b_props, "rescale_height", b_height );
 
@@ -587,6 +602,7 @@ static int transition_get_image( mlt_frame a_frame, uint8_t **image, mlt_image_f
 			mlt_properties_set( b_props, "rescale.interp", "none" );
 		}
 	}
+	mlt_log_debug(MLT_TRANSITION_SERVICE(transition), "requesting image B at resolution %dx%d\n", b_width, b_height);
 
 	// This is not a field-aware transform.
 	mlt_properties_set_int( b_props, "consumer_deinterlace", 1 );
@@ -658,7 +674,7 @@ static int transition_get_image( mlt_frame a_frame, uint8_t **image, mlt_image_f
 		}
 
 		// Factor scaling into the transformation based on output resolution.
-		if ( mlt_properties_get_int( properties, "distort" ) )
+		if ( distort )
 		{
 			scale_x = geom_scale_x * ( scale_x == 0 ? 1 : scale_x );
 			scale_y = geom_scale_y * ( scale_y == 0 ? 1 : scale_y );
