@@ -33,6 +33,7 @@ extern mlt_producer producer_kdenlivetitle_init( mlt_profile profile, mlt_servic
 extern mlt_transition transition_vqm_init( mlt_profile profile, mlt_service_type type, const char *id, void *arg );
 extern mlt_transition transition_qtblend_init( mlt_profile profile, mlt_service_type type, const char *id, void *arg );
 extern mlt_filter filter_qtblend_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
+extern mlt_filter filter_qtcrop_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
 
 #ifdef USE_FFTW
 extern mlt_filter filter_audiospectrum_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
@@ -58,8 +59,10 @@ MLT_REPOSITORY
 	MLT_REGISTER( producer_type, "kdenlivetitle", producer_kdenlivetitle_init );
 	MLT_REGISTER( transition_type, "qtblend", transition_qtblend_init );
 	MLT_REGISTER( filter_type, "qtblend", filter_qtblend_init );
+	MLT_REGISTER( filter_type, "qtcrop", filter_qtcrop_init );
 	MLT_REGISTER_METADATA( transition_type, "qtblend", metadata, "transition_qtblend.yml" );
 	MLT_REGISTER_METADATA( filter_type, "qtblend", metadata, "filter_qtblend.yml" );
+	MLT_REGISTER_METADATA( filter_type, "qtcrop", metadata, "filter_qtcrop.yml" );
 #ifdef USE_FFTW
 	MLT_REGISTER( filter_type, "audiospectrum", filter_audiospectrum_init );
 	MLT_REGISTER( filter_type, "lightshow", filter_lightshow_init );
